@@ -1,6 +1,9 @@
+// Copyright 2019 the Kurbo Authors
+// SPDX-License-Identifier: Apache-2.0 OR MIT
+
 //! Implementation of circle shape.
 
-use std::{
+use core::{
     f64::consts::{FRAC_PI_2, PI},
     iter,
     ops::{Add, Mul, Sub},
@@ -8,6 +11,9 @@ use std::{
 
 use crate::{Affine, Arc, ArcAppendIter, Ellipse, PathEl, Point, Rect, Shape, Vec2};
 
+#[cfg(not(feature = "std"))]
+use crate::common::FloatFuncs;
+
 /// A circle.
 #[derive(Clone, Copy, Default, Debug, PartialEq)]
 #[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
@@ -21,7 +27,7 @@ pub struct Circle {
 
 impl Circle {
     /// A new circle from center and radius.
-    #[inline]
+    #[inline(always)]
     pub fn new(center: impl Into<Point>, radius: f64) -> Circle {
         Circle {
             center: center.into(),
@@ -30,6 +36,7 @@ impl Circle {
     }
 
     /// Create a [`CircleSegment`] by cutting out parts of this circle.
+    #[inline(always)]
     pub fn segment(self, inner_radius: f64, start_angle: f64, sweep_angle: f64) -> CircleSegment {
         CircleSegment {
             center: self.center,
@@ -40,13 +47,17 @@ impl Circle {
         }
     }
 
-    /// Is this circle finite?
+    /// Is this circle [finite]?
+    ///
+    /// [finite]: f64::is_finite
     #[inline]
     pub fn is_finite(&self) -> bool {
         self.center.is_finite() && self.radius.is_finite()
     }
 
-    /// Is this circle NaN?
+    /// Is this circle [NaN]?
+    ///
+    /// [NaN]: f64::is_nan
     #[inline]
     pub fn is_nan(&self) -> bool {
         self.center.is_nan() || self.radius.is_nan()
@@ -94,7 +105,7 @@ pub struct CirclePathIter {
 }
 
 impl Shape for Circle {
-    type PathElementsIter = CirclePathIter;
+    type PathElementsIter<'iter> = CirclePathIter;
 
     fn path_elements(&self, tolerance: f64) -> CirclePathIter {
         let scaled_err = self.radius.abs() / tolerance;
@@ -143,6 +154,7 @@ impl Shape for Circle {
         Rect::new(x - r, y - r, x + r, y + r)
     }
 
+    #[inline(always)]
     fn as_circle(&self) -> Option<Circle> {
         Some(*self)
     }
@@ -162,11 +174,11 @@ impl Iterator for CirclePathIter {
         } else if ix <= self.n {
             let th1 = self.delta_th * (ix as f64);
             let th0 = th1 - self.delta_th;
-            let (c0, s0) = (th0.cos(), th0.sin());
-            let (c1, s1) = if ix == self.n {
-                (1.0, 0.0)
+            let (s0, c0) = th0.sin_cos();
+            let (s1, c1) = if ix == self.n {
+                (0.0, 1.0)
             } else {
-                (th1.cos(), th1.sin())
+                th1.sin_cos()
             };
             Some(PathEl::CurveTo(
                 Point::new(x + r * (c0 - a * s0), y + r * (s0 + a * c0)),
@@ -184,6 +196,9 @@ impl Iterator for CirclePathIter {
 /// A segment of a circle.
 ///
 /// If `inner_radius > 0`, then the shape will be a doughnut segment.
+#[derive(Clone, Copy, Debug, PartialEq)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct CircleSegment {
     /// The center.
     pub center: Point,
@@ -199,6 +214,7 @@ pub struct CircleSegment {
 
 impl CircleSegment {
     /// Create a `CircleSegment` out of its constituent parts.
+    #[inline(always)]
     pub fn new(
         center: impl Into<Point>,
         outer_radius: f64,
@@ -215,9 +231,43 @@ impl CircleSegment {
         }
     }
 
-    /// Is this circle segment finite?
+    /// Return an arc representing the outer radius.
+    #[must_use]
+    #[inline(always)]
+    pub fn outer_arc(&self) -> Arc {
+        Arc {
+            center: self.center,
+            radii: Vec2::new(self.outer_radius, self.outer_radius),
+            start_angle: self.start_angle,
+            sweep_angle: self.sweep_angle,
+            x_rotation: 0.0,
+        }
+    }
+
+    /// Return an arc representing the inner radius.
+    ///
+    /// This is [reversed] from the outer arc, so that it is in the
+    /// same direction as the arc that would be drawn (as the path
+    /// elements for this circle segment produce a closed path).
+    ///
+    /// [reversed]: Arc::reversed
+    #[must_use]
     #[inline]
-    pub fn is_finite(&self) -> bool {
+    pub fn inner_arc(&self) -> Arc {
+        Arc {
+            center: self.center,
+            radii: Vec2::new(self.inner_radius, self.inner_radius),
+            start_angle: self.start_angle + self.sweep_angle,
+            sweep_angle: -self.sweep_angle,
+            x_rotation: 0.0,
+        }
+    }
+
+    /// Is this circle segment [finite]?
+    ///
+    /// [finite]: f64::is_finite
+    #[inline]
+    pub const fn is_finite(&self) -> bool {
         self.center.is_finite()
             && self.outer_radius.is_finite()
             && self.inner_radius.is_finite()
@@ -225,9 +275,11 @@ impl CircleSegment {
             && self.sweep_angle.is_finite()
     }
 
-    /// Is this circle segment NaN?
+    /// Is this circle segment [NaN]?
+    ///
+    /// [NaN]: f64::is_nan
     #[inline]
-    pub fn is_nan(&self) -> bool {
+    pub const fn is_nan(&self) -> bool {
         self.center.is_nan()
             || self.outer_radius.is_nan()
             || self.inner_radius.is_nan()
@@ -260,7 +312,7 @@ impl Sub<Vec2> for CircleSegment {
     }
 }
 
-type CircleSegmentPathIter = std::iter::Chain<
+type CircleSegmentPathIter = iter::Chain<
     iter::Chain<
         iter::Chain<iter::Chain<iter::Once<PathEl>, iter::Once<PathEl>>, ArcAppendIter>,
         iter::Once<PathEl>,
@@ -269,7 +321,7 @@ type CircleSegmentPathIter = std::iter::Chain<
 >;
 
 impl Shape for CircleSegment {
-    type PathElementsIter = CircleSegmentPathIter;
+    type PathElementsIter<'iter> = CircleSegmentPathIter;
 
     fn path_elements(&self, tolerance: f64) -> CircleSegmentPathIter {
         iter::once(PathEl::MoveTo(point_on_circle(
@@ -284,16 +336,7 @@ impl Shape for CircleSegment {
             self.start_angle,
         ))))
         // outer arc
-        .chain(
-            Arc {
-                center: self.center,
-                radii: Vec2::new(self.outer_radius, self.outer_radius),
-                start_angle: self.start_angle,
-                sweep_angle: self.sweep_angle,
-                x_rotation: 0.0,
-            }
-            .append_iter(tolerance),
-        )
+        .chain(self.outer_arc().append_iter(tolerance))
         // second radius
         .chain(iter::once(PathEl::LineTo(point_on_circle(
             self.center,
@@ -301,16 +344,7 @@ impl Shape for CircleSegment {
             self.start_angle + self.sweep_angle,
         ))))
         // inner arc
-        .chain(
-            Arc {
-                center: self.center,
-                radii: Vec2::new(self.inner_radius, self.inner_radius),
-                start_angle: self.start_angle + self.sweep_angle,
-                sweep_angle: -self.sweep_angle,
-                x_rotation: 0.0,
-            }
-            .append_iter(tolerance),
-        )
+        .chain(self.inner_arc().append_iter(tolerance))
     }
 
     #[inline]
@@ -349,6 +383,16 @@ impl Shape for CircleSegment {
     }
 }
 
+#[inline]
+fn point_on_circle(center: Point, radius: f64, angle: f64) -> Point {
+    let (angle_sin, angle_cos) = angle.sin_cos();
+    center
+        + Vec2 {
+            x: angle_cos * radius,
+            y: angle_sin * radius,
+        }
+}
+
 #[cfg(test)]
 mod tests {
     use crate::{Circle, Point, Shape};
@@ -357,7 +401,7 @@ mod tests {
     fn assert_approx_eq(x: f64, y: f64) {
         // Note: we might want to be more rigorous in testing the accuracy
         // of the conversion into Béziers. But this seems good enough.
-        assert!((x - y).abs() < 1e-7, "{} != {}", x, y);
+        assert!((x - y).abs() < 1e-7, "{x} != {y}");
     }
 
     #[test]
@@ -382,12 +426,3 @@ mod tests {
         assert_eq!(c_neg_radius.winding(center), p_neg_radius.winding(center));
     }
 }
-
-#[inline]
-fn point_on_circle(center: Point, radius: f64, angle: f64) -> Point {
-    center
-        + Vec2 {
-            x: angle.cos() * radius,
-            y: angle.sin() * radius,
-        }
-}
