@@ -1,20 +1,13 @@
-// Copyright 2021 The kurbo Authors.
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-// https://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
+// Copyright 2021 the Kurbo Authors
+// SPDX-License-Identifier: Apache-2.0 OR MIT
 
 //! A description of the radii for each corner of a rounded rectangle.
 
-use std::convert::From;
+use core::convert::From;
+
+#[allow(unused_imports)] // This is unused in later versions of Rust because of additions to core::f32
+#[cfg(not(feature = "std"))]
+use crate::common::FloatFuncs;
 
 /// Radii for each corner of a rounded rectangle.
 ///
@@ -39,9 +32,10 @@ pub struct RoundedRectRadii {
 }
 
 impl RoundedRectRadii {
-    /// Create a new RoundedRectRadii. This function takes radius values for
-    /// the four corners. The argument order is "top_left, top_right,
-    /// bottom_right, bottom_left", or clockwise starting from top_left.
+    /// Create a new `RoundedRectRadii`. This function takes radius values for
+    /// the four corners. The argument order is `top_left`, `top_right`,
+    /// `bottom_right`, `bottom_left`, or clockwise starting from `top_left`.
+    #[inline(always)]
     pub const fn new(top_left: f64, top_right: f64, bottom_right: f64, bottom_left: f64) -> Self {
         RoundedRectRadii {
             top_left,
@@ -51,8 +45,9 @@ impl RoundedRectRadii {
         }
     }
 
-    /// Create a new RoundedRectRadii from a single radius. The `radius`
+    /// Create a new `RoundedRectRadii` from a single radius. The `radius`
     /// argument will be set as the radius for all four corners.
+    #[inline(always)]
     pub const fn from_single_radius(radius: f64) -> Self {
         RoundedRectRadii {
             top_left: radius,
@@ -82,16 +77,16 @@ impl RoundedRectRadii {
         )
     }
 
-    /// Returns true if all radius values are finite.
-    pub fn is_finite(&self) -> bool {
+    /// Returns `true` if all radius values are finite.
+    pub const fn is_finite(&self) -> bool {
         self.top_left.is_finite()
             && self.top_right.is_finite()
             && self.bottom_right.is_finite()
             && self.bottom_left.is_finite()
     }
 
-    /// Returns true if any corner radius value is NaN.
-    pub fn is_nan(&self) -> bool {
+    /// Returns `true` if any corner radius value is NaN.
+    pub const fn is_nan(&self) -> bool {
         self.top_left.is_nan()
             || self.top_right.is_nan()
             || self.bottom_right.is_nan()
@@ -115,12 +110,14 @@ impl RoundedRectRadii {
 }
 
 impl From<f64> for RoundedRectRadii {
+    #[inline(always)]
     fn from(radius: f64) -> Self {
         RoundedRectRadii::from_single_radius(radius)
     }
 }
 
 impl From<(f64, f64, f64, f64)> for RoundedRectRadii {
+    #[inline(always)]
     fn from(radii: (f64, f64, f64, f64)) -> Self {
         RoundedRectRadii::new(radii.0, radii.1, radii.2, radii.3)
     }
