@@ -1,6 +1,8 @@
 use super::*;
 use rustix::process::Resource;
+use std::convert::TryInto;
 
+#[track_caller]
 fn check_unwrap<T>(prc: &Process, val: ProcResult<T>) -> Option<T> {
     match val {
         Ok(t) => Some(t),
@@ -458,7 +460,7 @@ fn test_proc_auxv() {
         if k != 16 {
             // for reasons i do not understand, getauxval(AT_HWCAP) doesn't return the expected
             // value
-            assert_eq!(v, unsafe { libc::getauxval(k) });
+            assert_eq!(v, unsafe { libc::getauxval(k.try_into().unwrap()).into() });
         }
     }
 }
@@ -533,7 +535,11 @@ fn test_schedstat() {
 
 #[test]
 fn test_fdtarget() {
-    // none of these values are valid, but were found by a fuzzer to crash procfs.  this
+    // https://github.com/eminence/procfs/issues/352
+    let x = FDTarget::from_str("onload:[udp:1:2032]").unwrap();
+    assert!(matches!(x, FDTarget::Unknown(..)));
+
+    // none of these below values are valid, but were found by a fuzzer to crash procfs.  this
     // test ensures that the crashes have been fixed
 
     let _ = FDTarget::from_str(":");
@@ -709,6 +715,11 @@ fn test_proc_status_for_kthreadd() {
     let status = kthreadd.status().unwrap();
     println!("{:?}", status);
 
+    // actually check that pid2 is kthreadd
+    if status.name != "kthreadd" {
+        return; // ok we can still ignore
+    }
+
     assert_eq!(status.pid, 2);
     assert_eq!(status.vmpeak, None);
     assert_eq!(status.vmsize, None);
