@@ -15,10 +15,9 @@ For some reason, we are almost 2x slower. Maybe because Skia uses clang's vector
 and we're using a manual implementation.
 */
 
-use tiny_skia_path::ScreenIntRect;
-
 use crate::{PremultipliedColorU8, SpreadMode, PixmapRef};
 
+use crate::geom::ScreenIntRect;
 use crate::pixmap::SubPixmapMut;
 use crate::wide::{f32x8, i32x8, u32x8};
 
@@ -32,8 +31,8 @@ pub struct Pipeline<'a, 'b: 'a> {
     pixmap_src: PixmapRef<'a>,
     pixmap_dst: &'a mut SubPixmapMut<'b>,
     ctx: &'a mut super::Context, // TODO: remove mut
-    clip_mask_ctx: super::ClipMaskCtx<'a>,
-    mask_ctx: super::AAMaskCtx,
+    mask_ctx: super::MaskCtx<'a>,
+    aa_mask_ctx: super::AAMaskCtx,
     r: f32x8,
     g: f32x8,
     b: f32x8,
@@ -67,7 +66,10 @@ pub const STAGES: &[StageFn; super::STAGES_COUNT] = &[
     seed_shader,
     load_dst,
     store,
+    load_dst_u8,
+    store_u8,
     gather,
+    load_mask_u8,
     mask_u8,
     scale_u8,
     lerp_u8,
@@ -128,8 +130,8 @@ pub fn start(
     functions: &[StageFn],
     functions_tail: &[StageFn],
     rect: &ScreenIntRect,
-    mask_ctx: super::AAMaskCtx,
-    clip_mask_ctx: super::ClipMaskCtx,
+    aa_mask_ctx: super::AAMaskCtx,
+    mask_ctx: super::MaskCtx,
     ctx: &mut super::Context,
     pixmap_src: PixmapRef,
     pixmap_dst: &mut SubPixmapMut,
@@ -139,8 +141,8 @@ pub fn start(
         functions: &[],
         pixmap_src,
         pixmap_dst,
-        clip_mask_ctx,
         mask_ctx,
+        aa_mask_ctx,
         ctx,
         r: f32x8::default(),
         g: f32x8::default(),
@@ -265,6 +267,28 @@ pub fn store(p: &mut Pipeline) {
     p.next_stage();
 }
 
+pub fn store_tail(p: &mut Pipeline) {
+    store_8888_tail(&p.r, &p.g, &p.b, &p.a, p.tail, p.pixmap_dst.slice_at_xy(p.dx, p.dy));
+    p.next_stage();
+}
+
+// Currently, all mask/A8 pixmaps are handled by lowp.
+pub fn load_dst_u8(_: &mut Pipeline) {
+    // unreachable
+}
+
+pub fn load_dst_u8_tail(_: &mut Pipeline) {
+    // unreachable
+}
+
+pub fn store_u8(_: &mut Pipeline) {
+    // unreachable
+}
+
+pub fn store_u8_tail(_: &mut Pipeline) {
+    // unreachable
+}
+
 pub fn gather(p: &mut Pipeline) {
     let ix = gather_ix(p.pixmap_src, p.r, p.g);
     load_8888(&p.pixmap_src.gather(ix), &mut p.r, &mut p.g, &mut p.b, &mut p.a);
@@ -289,16 +313,15 @@ fn ulp_sub(v: f32) -> f32 {
     bytemuck::cast::<u32, f32>(bytemuck::cast::<f32, u32>(v) - 1)
 }
 
-pub fn store_tail(p: &mut Pipeline) {
-    store_8888_tail(&p.r, &p.g, &p.b, &p.a, p.tail, p.pixmap_dst.slice_at_xy(p.dx, p.dy));
-    p.next_stage();
+fn load_mask_u8(_: &mut Pipeline) {
+    // unreachable
 }
 
 fn mask_u8(p: &mut Pipeline) {
-    let offset = p.clip_mask_ctx.offset(p.dx, p.dy);
+    let offset = p.mask_ctx.offset(p.dx, p.dy);
     let mut c = [0.0; 8];
     for i in 0..p.tail {
-        c[i] = p.clip_mask_ctx.data[offset + i] as f32;
+        c[i] = p.mask_ctx.data[offset + i] as f32;
     }
     let c = f32x8::from(c) / f32x8::splat(255.0);
 
@@ -316,7 +339,7 @@ fn mask_u8(p: &mut Pipeline) {
 
 fn scale_u8(p: &mut Pipeline) {
     // Load u8xTail and cast it to f32x8.
-    let data = p.mask_ctx.copy_at_xy(p.dx, p.dy, p.tail);
+    let data = p.aa_mask_ctx.copy_at_xy(p.dx, p.dy, p.tail);
     let c = f32x8::from([data[0] as f32, data[1] as f32, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]);
     let c = c / f32x8::splat(255.0);
 
@@ -330,7 +353,7 @@ fn scale_u8(p: &mut Pipeline) {
 
 fn lerp_u8(p: &mut Pipeline) {
     // Load u8xTail and cast it to f32x8.
-    let data = p.mask_ctx.copy_at_xy(p.dx, p.dy, p.tail);
+    let data = p.aa_mask_ctx.copy_at_xy(p.dx, p.dy, p.tail);
     let c = f32x8::from([data[0] as f32, data[1] as f32, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]);
     let c = c / f32x8::splat(255.0);
 
