@@ -37,13 +37,13 @@ impl RuntimeMetrics {
     /// ```
     /// use tokio::runtime::Handle;
     ///
-    /// #[tokio::main]
-    /// async fn main() {
-    ///     let metrics = Handle::current().metrics();
+    /// # #[tokio::main(flavor = "current_thread")]
+    /// # async fn main() {
+    /// let metrics = Handle::current().metrics();
     ///
-    ///     let n = metrics.num_workers();
-    ///     println!("Runtime is using {} workers", n);
-    /// }
+    /// let n = metrics.num_workers();
+    /// println!("Runtime is using {} workers", n);
+    /// # }
     /// ```
     pub fn num_workers(&self) -> usize {
         self.handle.inner.num_workers()
@@ -54,18 +54,22 @@ impl RuntimeMetrics {
     /// This counter increases when a task is spawned and decreases when a
     /// task exits.
     ///
+    /// Note: When using the multi-threaded runtime this number may not
+    /// not have strong consistency i.e. no tasks may be running but the metric
+    /// reports otherwise.
+    ///
     /// # Examples
     ///
     /// ```
     /// use tokio::runtime::Handle;
     ///
-    /// #[tokio::main]
-    /// async fn main() {
-    ///    let metrics = Handle::current().metrics();
+    /// # #[tokio::main(flavor = "current_thread")]
+    /// # async fn main() {
+    /// let metrics = Handle::current().metrics();
     ///
-    ///     let n = metrics.num_alive_tasks();
-    ///     println!("Runtime has {} alive tasks", n);
-    /// }
+    /// let n = metrics.num_alive_tasks();
+    /// println!("Runtime has {} alive tasks", n);
+    /// # }
     /// ```
     pub fn num_alive_tasks(&self) -> usize {
         self.handle.inner.num_alive_tasks()
@@ -85,13 +89,13 @@ impl RuntimeMetrics {
     /// ```
     /// use tokio::runtime::Handle;
     ///
-    /// #[tokio::main]
-    /// async fn main() {
-    ///     let metrics = Handle::current().metrics();
+    /// # #[tokio::main(flavor = "current_thread")]
+    /// # async fn main() {
+    /// let metrics = Handle::current().metrics();
     ///
-    ///     let n = metrics.global_queue_depth();
-    ///     println!("{} tasks currently pending in the runtime's global queue", n);
-    /// }
+    /// let n = metrics.global_queue_depth();
+    /// println!("{} tasks currently pending in the runtime's global queue", n);
+    /// # }
     /// ```
     pub fn global_queue_depth(&self) -> usize {
         self.handle.inner.injection_queue_depth()
@@ -126,13 +130,13 @@ impl RuntimeMetrics {
         /// ```
         /// use tokio::runtime::Handle;
         ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
         ///
-        ///     let n = metrics.worker_total_busy_duration(0);
-        ///     println!("worker 0 was busy for a total of {:?}", n);
-        /// }
+        /// let n = metrics.worker_total_busy_duration(0);
+        /// println!("worker 0 was busy for a total of {:?}", n);
+        /// # }
         /// ```
         pub fn worker_total_busy_duration(&self, worker: usize) -> Duration {
             let nanos = self
@@ -171,13 +175,13 @@ impl RuntimeMetrics {
         /// ```
         /// use tokio::runtime::Handle;
         ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
         ///
-        ///     let n = metrics.worker_park_count(0);
-        ///     println!("worker 0 parked {} times", n);
-        /// }
+        /// let n = metrics.worker_park_count(0);
+        /// println!("worker 0 parked {} times", n);
+        /// # }
         /// ```
         pub fn worker_park_count(&self, worker: usize) -> u64 {
             self.handle
@@ -219,19 +223,19 @@ impl RuntimeMetrics {
         /// ```
         /// use tokio::runtime::Handle;
         ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
-        ///     let n = metrics.worker_park_unpark_count(0);
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
+        /// let n = metrics.worker_park_unpark_count(0);
         ///
-        ///     println!("worker 0 parked and unparked {} times", n);
+        /// println!("worker 0 parked and unparked {} times", n);
         ///
-        ///     if n % 2 == 0 {
-        ///         println!("worker 0 is active");
-        ///     } else {
-        ///         println!("worker 0 is parked");
-        ///     }
+        /// if n % 2 == 0 {
+        ///     println!("worker 0 is active");
+        /// } else {
+        ///     println!("worker 0 is parked");
         /// }
+        /// # }
         /// ```
         pub fn worker_park_unpark_count(&self, worker: usize) -> u64 {
             self.handle
@@ -252,19 +256,22 @@ impl RuntimeMetrics {
         /// # Examples
         ///
         /// ```
+        /// # #[cfg(not(target_family = "wasm"))]
+        /// # {
         /// use tokio::runtime::Handle;
         ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let _ = tokio::task::spawn_blocking(move || {
-        ///         // Stand-in for compute-heavy work or using synchronous APIs
-        ///         1 + 1
-        ///     }).await;
-        ///     let metrics = Handle::current().metrics();
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let _ = tokio::task::spawn_blocking(move || {
+        ///     // Stand-in for compute-heavy work or using synchronous APIs
+        ///     1 + 1
+        /// }).await;
+        /// let metrics = Handle::current().metrics();
         ///
-        ///     let n = metrics.num_blocking_threads();
-        ///     println!("Runtime has created {} threads", n);
-        /// }
+        /// let n = metrics.num_blocking_threads();
+        /// println!("Runtime has created {} threads", n);
+        /// # }
+        /// # }
         /// ```
         pub fn num_blocking_threads(&self) -> usize {
             self.handle.inner.num_blocking_threads()
@@ -282,6 +289,8 @@ impl RuntimeMetrics {
         /// # Examples
         ///
         /// ```
+        /// # #[cfg(not(target_family = "wasm"))]
+        /// # {
         /// use tokio::runtime::Handle;
         ///
         /// #[tokio::main]
@@ -295,6 +304,7 @@ impl RuntimeMetrics {
         ///     let n = metrics.num_idle_blocking_threads();
         ///     println!("Runtime has {} idle blocking thread pool threads", n);
         /// }
+        /// # }
         /// ```
         pub fn num_idle_blocking_threads(&self) -> usize {
             self.handle.inner.num_idle_blocking_threads()
@@ -328,13 +338,13 @@ impl RuntimeMetrics {
         /// ```
         /// use tokio::runtime::Handle;
         ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
         ///
-        ///     let id = metrics.worker_thread_id(0);
-        ///     println!("worker 0 has id {:?}", id);
-        /// }
+        /// let id = metrics.worker_thread_id(0);
+        /// println!("worker 0 has id {:?}", id);
+        /// # }
         /// ```
         pub fn worker_thread_id(&self, worker: usize) -> Option<ThreadId> {
             self.handle
@@ -342,353 +352,6 @@ impl RuntimeMetrics {
                 .worker_metrics(worker)
                 .thread_id()
         }
-    }
-
-    feature! {
-        #![all(
-            tokio_unstable,
-            target_has_atomic = "64"
-        )]
-        /// Returns the number of tasks spawned in this runtime since it was created.
-        ///
-        /// This count starts at zero when the runtime is created and increases by one each time a task is spawned.
-        ///
-        /// The counter is monotonically increasing. It is never decremented or
-        /// reset to zero.
-        ///
-        /// # Examples
-        ///
-        /// ```
-        /// use tokio::runtime::Handle;
-        ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///    let metrics = Handle::current().metrics();
-        ///
-        ///     let n = metrics.spawned_tasks_count();
-        ///     println!("Runtime has had {} tasks spawned", n);
-        /// }
-        /// ```
-        pub fn spawned_tasks_count(&self) -> u64 {
-            self.handle.inner.spawned_tasks_count()
-        }
-
-        /// Returns the number of tasks scheduled from **outside** of the runtime.
-        ///
-        /// The remote schedule count starts at zero when the runtime is created and
-        /// increases by one each time a task is woken from **outside** of the
-        /// runtime. This usually means that a task is spawned or notified from a
-        /// non-runtime thread and must be queued using the Runtime's injection
-        /// queue, which tends to be slower.
-        ///
-        /// The counter is monotonically increasing. It is never decremented or
-        /// reset to zero.
-        ///
-        /// # Examples
-        ///
-        /// ```
-        /// use tokio::runtime::Handle;
-        ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
-        ///
-        ///     let n = metrics.remote_schedule_count();
-        ///     println!("{} tasks were scheduled from outside the runtime", n);
-        /// }
-        /// ```
-        pub fn remote_schedule_count(&self) -> u64 {
-            self.handle
-                .inner
-                .scheduler_metrics()
-                .remote_schedule_count
-                .load(Relaxed)
-        }
-
-        /// Returns the number of times that tasks have been forced to yield back to the scheduler
-        /// after exhausting their task budgets.
-        ///
-        /// This count starts at zero when the runtime is created and increases by one each time a task yields due to exhausting its budget.
-        ///
-        /// The counter is monotonically increasing. It is never decremented or
-        /// reset to zero.
-        pub fn budget_forced_yield_count(&self) -> u64 {
-            self.handle
-                .inner
-                .scheduler_metrics()
-                .budget_forced_yield_count
-                .load(Relaxed)
-        }
-
-        /// Returns the number of times the given worker thread unparked but
-        /// performed no work before parking again.
-        ///
-        /// The worker no-op count starts at zero when the runtime is created and
-        /// increases by one each time the worker unparks the thread but finds no
-        /// new work and goes back to sleep. This indicates a false-positive wake up.
-        ///
-        /// The counter is monotonically increasing. It is never decremented or
-        /// reset to zero.
-        ///
-        /// # Arguments
-        ///
-        /// `worker` is the index of the worker being queried. The given value must
-        /// be between 0 and `num_workers()`. The index uniquely identifies a single
-        /// worker and will continue to identify the worker throughout the lifetime
-        /// of the runtime instance.
-        ///
-        /// # Panics
-        ///
-        /// The method panics when `worker` represents an invalid worker, i.e. is
-        /// greater than or equal to `num_workers()`.
-        ///
-        /// # Examples
-        ///
-        /// ```
-        /// use tokio::runtime::Handle;
-        ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
-        ///
-        ///     let n = metrics.worker_noop_count(0);
-        ///     println!("worker 0 had {} no-op unparks", n);
-        /// }
-        /// ```
-        pub fn worker_noop_count(&self, worker: usize) -> u64 {
-            self.handle
-                .inner
-                .worker_metrics(worker)
-                .noop_count
-                .load(Relaxed)
-        }
-
-        /// Returns the number of tasks the given worker thread stole from
-        /// another worker thread.
-        ///
-        /// This metric only applies to the **multi-threaded** runtime and will
-        /// always return `0` when using the current thread runtime.
-        ///
-        /// The worker steal count starts at zero when the runtime is created and
-        /// increases by `N` each time the worker has processed its scheduled queue
-        /// and successfully steals `N` more pending tasks from another worker.
-        ///
-        /// The counter is monotonically increasing. It is never decremented or
-        /// reset to zero.
-        ///
-        /// # Arguments
-        ///
-        /// `worker` is the index of the worker being queried. The given value must
-        /// be between 0 and `num_workers()`. The index uniquely identifies a single
-        /// worker and will continue to identify the worker throughout the lifetime
-        /// of the runtime instance.
-        ///
-        /// # Panics
-        ///
-        /// The method panics when `worker` represents an invalid worker, i.e. is
-        /// greater than or equal to `num_workers()`.
-        ///
-        /// # Examples
-        ///
-        /// ```
-        /// use tokio::runtime::Handle;
-        ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
-        ///
-        ///     let n = metrics.worker_steal_count(0);
-        ///     println!("worker 0 has stolen {} tasks", n);
-        /// }
-        /// ```
-        pub fn worker_steal_count(&self, worker: usize) -> u64 {
-            self.handle
-                .inner
-                .worker_metrics(worker)
-                .steal_count
-                .load(Relaxed)
-        }
-
-        /// Returns the number of times the given worker thread stole tasks from
-        /// another worker thread.
-        ///
-        /// This metric only applies to the **multi-threaded** runtime and will
-        /// always return `0` when using the current thread runtime.
-        ///
-        /// The worker steal count starts at zero when the runtime is created and
-        /// increases by one each time the worker has processed its scheduled queue
-        /// and successfully steals more pending tasks from another worker.
-        ///
-        /// The counter is monotonically increasing. It is never decremented or
-        /// reset to zero.
-        ///
-        /// # Arguments
-        ///
-        /// `worker` is the index of the worker being queried. The given value must
-        /// be between 0 and `num_workers()`. The index uniquely identifies a single
-        /// worker and will continue to identify the worker throughout the lifetime
-        /// of the runtime instance.
-        ///
-        /// # Panics
-        ///
-        /// The method panics when `worker` represents an invalid worker, i.e. is
-        /// greater than or equal to `num_workers()`.
-        ///
-        /// # Examples
-        ///
-        /// ```
-        /// use tokio::runtime::Handle;
-        ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
-        ///
-        ///     let n = metrics.worker_steal_operations(0);
-        ///     println!("worker 0 has stolen tasks {} times", n);
-        /// }
-        /// ```
-        pub fn worker_steal_operations(&self, worker: usize) -> u64 {
-            self.handle
-                .inner
-                .worker_metrics(worker)
-                .steal_operations
-                .load(Relaxed)
-        }
-
-        /// Returns the number of tasks the given worker thread has polled.
-        ///
-        /// The worker poll count starts at zero when the runtime is created and
-        /// increases by one each time the worker polls a scheduled task.
-        ///
-        /// The counter is monotonically increasing. It is never decremented or
-        /// reset to zero.
-        ///
-        /// # Arguments
-        ///
-        /// `worker` is the index of the worker being queried. The given value must
-        /// be between 0 and `num_workers()`. The index uniquely identifies a single
-        /// worker and will continue to identify the worker throughout the lifetime
-        /// of the runtime instance.
-        ///
-        /// # Panics
-        ///
-        /// The method panics when `worker` represents an invalid worker, i.e. is
-        /// greater than or equal to `num_workers()`.
-        ///
-        /// # Examples
-        ///
-        /// ```
-        /// use tokio::runtime::Handle;
-        ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
-        ///
-        ///     let n = metrics.worker_poll_count(0);
-        ///     println!("worker 0 has polled {} tasks", n);
-        /// }
-        /// ```
-        pub fn worker_poll_count(&self, worker: usize) -> u64 {
-            self.handle
-                .inner
-                .worker_metrics(worker)
-                .poll_count
-                .load(Relaxed)
-        }
-
-        /// Returns the number of tasks scheduled from **within** the runtime on the
-        /// given worker's local queue.
-        ///
-        /// The local schedule count starts at zero when the runtime is created and
-        /// increases by one each time a task is woken from **inside** of the
-        /// runtime on the given worker. This usually means that a task is spawned
-        /// or notified from within a runtime thread and will be queued on the
-        /// worker-local queue.
-        ///
-        /// The counter is monotonically increasing. It is never decremented or
-        /// reset to zero.
-        ///
-        /// # Arguments
-        ///
-        /// `worker` is the index of the worker being queried. The given value must
-        /// be between 0 and `num_workers()`. The index uniquely identifies a single
-        /// worker and will continue to identify the worker throughout the lifetime
-        /// of the runtime instance.
-        ///
-        /// # Panics
-        ///
-        /// The method panics when `worker` represents an invalid worker, i.e. is
-        /// greater than or equal to `num_workers()`.
-        ///
-        /// # Examples
-        ///
-        /// ```
-        /// use tokio::runtime::Handle;
-        ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
-        ///
-        ///     let n = metrics.worker_local_schedule_count(0);
-        ///     println!("{} tasks were scheduled on the worker's local queue", n);
-        /// }
-        /// ```
-        pub fn worker_local_schedule_count(&self, worker: usize) -> u64 {
-            self.handle
-                .inner
-                .worker_metrics(worker)
-                .local_schedule_count
-                .load(Relaxed)
-        }
-
-        /// Returns the number of times the given worker thread saturated its local
-        /// queue.
-        ///
-        /// This metric only applies to the **multi-threaded** scheduler.
-        ///
-        /// The worker overflow count starts at zero when the runtime is created and
-        /// increases by one each time the worker attempts to schedule a task
-        /// locally, but its local queue is full. When this happens, half of the
-        /// local queue is moved to the injection queue.
-        ///
-        /// The counter is monotonically increasing. It is never decremented or
-        /// reset to zero.
-        ///
-        /// # Arguments
-        ///
-        /// `worker` is the index of the worker being queried. The given value must
-        /// be between 0 and `num_workers()`. The index uniquely identifies a single
-        /// worker and will continue to identify the worker throughout the lifetime
-        /// of the runtime instance.
-        ///
-        /// # Panics
-        ///
-        /// The method panics when `worker` represents an invalid worker, i.e. is
-        /// greater than or equal to `num_workers()`.
-        ///
-        /// # Examples
-        ///
-        /// ```
-        /// use tokio::runtime::Handle;
-        ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
-        ///
-        ///     let n = metrics.worker_overflow_count(0);
-        ///     println!("worker 0 has overflowed its queue {} times", n);
-        /// }
-        /// ```
-        pub fn worker_overflow_count(&self, worker: usize) -> u64 {
-            self.handle
-                .inner
-                .worker_metrics(worker)
-                .overflow_count
-                .load(Relaxed)
-        }
-    }
-
-    cfg_unstable_metrics! {
 
         /// Renamed to [`RuntimeMetrics::global_queue_depth`]
         #[deprecated = "Renamed to global_queue_depth"]
@@ -723,13 +386,13 @@ impl RuntimeMetrics {
         /// ```
         /// use tokio::runtime::Handle;
         ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
         ///
-        ///     let n = metrics.worker_local_queue_depth(0);
-        ///     println!("{} tasks currently pending in worker 0's local queue", n);
-        /// }
+        /// let n = metrics.worker_local_queue_depth(0);
+        /// println!("{} tasks currently pending in worker 0's local queue", n);
+        /// # }
         /// ```
         pub fn worker_local_queue_depth(&self, worker: usize) -> usize {
             self.handle.inner.worker_local_queue_depth(worker)
@@ -884,13 +547,375 @@ impl RuntimeMetrics {
         pub fn poll_count_histogram_bucket_range(&self, bucket: usize) -> Range<Duration> {
             self.poll_time_histogram_bucket_range(bucket)
         }
+
+        /// Returns the number of tasks currently scheduled in the blocking
+        /// thread pool, spawned using `spawn_blocking`.
+        ///
+        /// This metric returns the **current** number of tasks pending in
+        /// blocking thread pool. As such, the returned value may increase
+        /// or decrease as new tasks are scheduled and processed.
+        ///
+        /// # Examples
+        ///
+        /// ```
+        /// use tokio::runtime::Handle;
+        ///
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
+        ///
+        /// let n = metrics.blocking_queue_depth();
+        /// println!("{} tasks currently pending in the blocking thread pool", n);
+        /// # }
+        /// ```
+        pub fn blocking_queue_depth(&self) -> usize {
+            self.handle.inner.blocking_queue_depth()
+        }
     }
 
     feature! {
-    #![all(
-        tokio_unstable,
-        target_has_atomic = "64"
-    )]
+        #![all(
+            tokio_unstable,
+            target_has_atomic = "64"
+        )]
+        /// Returns the number of tasks spawned in this runtime since it was created.
+        ///
+        /// This count starts at zero when the runtime is created and increases by one each time a task is spawned.
+        ///
+        /// The counter is monotonically increasing. It is never decremented or
+        /// reset to zero.
+        ///
+        /// # Examples
+        ///
+        /// ```
+        /// use tokio::runtime::Handle;
+        ///
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
+        ///
+        /// let n = metrics.spawned_tasks_count();
+        /// println!("Runtime has had {} tasks spawned", n);
+        /// # }
+        /// ```
+        pub fn spawned_tasks_count(&self) -> u64 {
+            self.handle.inner.spawned_tasks_count()
+        }
+
+        /// Returns the number of tasks scheduled from **outside** of the runtime.
+        ///
+        /// The remote schedule count starts at zero when the runtime is created and
+        /// increases by one each time a task is woken from **outside** of the
+        /// runtime. This usually means that a task is spawned or notified from a
+        /// non-runtime thread and must be queued using the Runtime's injection
+        /// queue, which tends to be slower.
+        ///
+        /// The counter is monotonically increasing. It is never decremented or
+        /// reset to zero.
+        ///
+        /// # Examples
+        ///
+        /// ```
+        /// use tokio::runtime::Handle;
+        ///
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
+        ///
+        /// let n = metrics.remote_schedule_count();
+        /// println!("{} tasks were scheduled from outside the runtime", n);
+        /// # }
+        /// ```
+        pub fn remote_schedule_count(&self) -> u64 {
+            self.handle
+                .inner
+                .scheduler_metrics()
+                .remote_schedule_count
+                .load(Relaxed)
+        }
+
+        /// Returns the number of times that tasks have been forced to yield back to the scheduler
+        /// after exhausting their task budgets.
+        ///
+        /// This count starts at zero when the runtime is created and increases by one each time a task yields due to exhausting its budget.
+        ///
+        /// The counter is monotonically increasing. It is never decremented or
+        /// reset to zero.
+        pub fn budget_forced_yield_count(&self) -> u64 {
+            self.handle
+                .inner
+                .scheduler_metrics()
+                .budget_forced_yield_count
+                .load(Relaxed)
+        }
+
+        /// Returns the number of times the given worker thread unparked but
+        /// performed no work before parking again.
+        ///
+        /// The worker no-op count starts at zero when the runtime is created and
+        /// increases by one each time the worker unparks the thread but finds no
+        /// new work and goes back to sleep. This indicates a false-positive wake up.
+        ///
+        /// The counter is monotonically increasing. It is never decremented or
+        /// reset to zero.
+        ///
+        /// # Arguments
+        ///
+        /// `worker` is the index of the worker being queried. The given value must
+        /// be between 0 and `num_workers()`. The index uniquely identifies a single
+        /// worker and will continue to identify the worker throughout the lifetime
+        /// of the runtime instance.
+        ///
+        /// # Panics
+        ///
+        /// The method panics when `worker` represents an invalid worker, i.e. is
+        /// greater than or equal to `num_workers()`.
+        ///
+        /// # Examples
+        ///
+        /// ```
+        /// use tokio::runtime::Handle;
+        ///
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
+        ///
+        /// let n = metrics.worker_noop_count(0);
+        /// println!("worker 0 had {} no-op unparks", n);
+        /// # }
+        /// ```
+        pub fn worker_noop_count(&self, worker: usize) -> u64 {
+            self.handle
+                .inner
+                .worker_metrics(worker)
+                .noop_count
+                .load(Relaxed)
+        }
+
+        /// Returns the number of tasks the given worker thread stole from
+        /// another worker thread.
+        ///
+        /// This metric only applies to the **multi-threaded** runtime and will
+        /// always return `0` when using the current thread runtime.
+        ///
+        /// The worker steal count starts at zero when the runtime is created and
+        /// increases by `N` each time the worker has processed its scheduled queue
+        /// and successfully steals `N` more pending tasks from another worker.
+        ///
+        /// The counter is monotonically increasing. It is never decremented or
+        /// reset to zero.
+        ///
+        /// # Arguments
+        ///
+        /// `worker` is the index of the worker being queried. The given value must
+        /// be between 0 and `num_workers()`. The index uniquely identifies a single
+        /// worker and will continue to identify the worker throughout the lifetime
+        /// of the runtime instance.
+        ///
+        /// # Panics
+        ///
+        /// The method panics when `worker` represents an invalid worker, i.e. is
+        /// greater than or equal to `num_workers()`.
+        ///
+        /// # Examples
+        ///
+        /// ```
+        /// use tokio::runtime::Handle;
+        ///
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
+        ///
+        /// let n = metrics.worker_steal_count(0);
+        /// println!("worker 0 has stolen {} tasks", n);
+        /// # }
+        /// ```
+        pub fn worker_steal_count(&self, worker: usize) -> u64 {
+            self.handle
+                .inner
+                .worker_metrics(worker)
+                .steal_count
+                .load(Relaxed)
+        }
+
+        /// Returns the number of times the given worker thread stole tasks from
+        /// another worker thread.
+        ///
+        /// This metric only applies to the **multi-threaded** runtime and will
+        /// always return `0` when using the current thread runtime.
+        ///
+        /// The worker steal count starts at zero when the runtime is created and
+        /// increases by one each time the worker has processed its scheduled queue
+        /// and successfully steals more pending tasks from another worker.
+        ///
+        /// The counter is monotonically increasing. It is never decremented or
+        /// reset to zero.
+        ///
+        /// # Arguments
+        ///
+        /// `worker` is the index of the worker being queried. The given value must
+        /// be between 0 and `num_workers()`. The index uniquely identifies a single
+        /// worker and will continue to identify the worker throughout the lifetime
+        /// of the runtime instance.
+        ///
+        /// # Panics
+        ///
+        /// The method panics when `worker` represents an invalid worker, i.e. is
+        /// greater than or equal to `num_workers()`.
+        ///
+        /// # Examples
+        ///
+        /// ```
+        /// use tokio::runtime::Handle;
+        ///
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
+        ///
+        /// let n = metrics.worker_steal_operations(0);
+        /// println!("worker 0 has stolen tasks {} times", n);
+        /// # }
+        /// ```
+        pub fn worker_steal_operations(&self, worker: usize) -> u64 {
+            self.handle
+                .inner
+                .worker_metrics(worker)
+                .steal_operations
+                .load(Relaxed)
+        }
+
+        /// Returns the number of tasks the given worker thread has polled.
+        ///
+        /// The worker poll count starts at zero when the runtime is created and
+        /// increases by one each time the worker polls a scheduled task.
+        ///
+        /// The counter is monotonically increasing. It is never decremented or
+        /// reset to zero.
+        ///
+        /// # Arguments
+        ///
+        /// `worker` is the index of the worker being queried. The given value must
+        /// be between 0 and `num_workers()`. The index uniquely identifies a single
+        /// worker and will continue to identify the worker throughout the lifetime
+        /// of the runtime instance.
+        ///
+        /// # Panics
+        ///
+        /// The method panics when `worker` represents an invalid worker, i.e. is
+        /// greater than or equal to `num_workers()`.
+        ///
+        /// # Examples
+        ///
+        /// ```
+        /// use tokio::runtime::Handle;
+        ///
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
+        ///
+        /// let n = metrics.worker_poll_count(0);
+        /// println!("worker 0 has polled {} tasks", n);
+        /// # }
+        /// ```
+        pub fn worker_poll_count(&self, worker: usize) -> u64 {
+            self.handle
+                .inner
+                .worker_metrics(worker)
+                .poll_count
+                .load(Relaxed)
+        }
+
+        /// Returns the number of tasks scheduled from **within** the runtime on the
+        /// given worker's local queue.
+        ///
+        /// The local schedule count starts at zero when the runtime is created and
+        /// increases by one each time a task is woken from **inside** of the
+        /// runtime on the given worker. This usually means that a task is spawned
+        /// or notified from within a runtime thread and will be queued on the
+        /// worker-local queue.
+        ///
+        /// The counter is monotonically increasing. It is never decremented or
+        /// reset to zero.
+        ///
+        /// # Arguments
+        ///
+        /// `worker` is the index of the worker being queried. The given value must
+        /// be between 0 and `num_workers()`. The index uniquely identifies a single
+        /// worker and will continue to identify the worker throughout the lifetime
+        /// of the runtime instance.
+        ///
+        /// # Panics
+        ///
+        /// The method panics when `worker` represents an invalid worker, i.e. is
+        /// greater than or equal to `num_workers()`.
+        ///
+        /// # Examples
+        ///
+        /// ```
+        /// use tokio::runtime::Handle;
+        ///
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
+        ///
+        /// let n = metrics.worker_local_schedule_count(0);
+        /// println!("{} tasks were scheduled on the worker's local queue", n);
+        /// # }
+        /// ```
+        pub fn worker_local_schedule_count(&self, worker: usize) -> u64 {
+            self.handle
+                .inner
+                .worker_metrics(worker)
+                .local_schedule_count
+                .load(Relaxed)
+        }
+
+        /// Returns the number of times the given worker thread saturated its local
+        /// queue.
+        ///
+        /// This metric only applies to the **multi-threaded** scheduler.
+        ///
+        /// The worker overflow count starts at zero when the runtime is created and
+        /// increases by one each time the worker attempts to schedule a task
+        /// locally, but its local queue is full. When this happens, half of the
+        /// local queue is moved to the injection queue.
+        ///
+        /// The counter is monotonically increasing. It is never decremented or
+        /// reset to zero.
+        ///
+        /// # Arguments
+        ///
+        /// `worker` is the index of the worker being queried. The given value must
+        /// be between 0 and `num_workers()`. The index uniquely identifies a single
+        /// worker and will continue to identify the worker throughout the lifetime
+        /// of the runtime instance.
+        ///
+        /// # Panics
+        ///
+        /// The method panics when `worker` represents an invalid worker, i.e. is
+        /// greater than or equal to `num_workers()`.
+        ///
+        /// # Examples
+        ///
+        /// ```
+        /// use tokio::runtime::Handle;
+        ///
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
+        ///
+        /// let n = metrics.worker_overflow_count(0);
+        /// println!("worker 0 has overflowed its queue {} times", n);
+        /// # }
+        /// ```
+        pub fn worker_overflow_count(&self, worker: usize) -> u64 {
+            self.handle
+                .inner
+                .worker_metrics(worker)
+                .overflow_count
+                .load(Relaxed)
+        }
+
         /// Returns the number of times the given worker polled tasks with a poll
         /// duration within the given bucket's range.
         ///
@@ -984,13 +1009,13 @@ impl RuntimeMetrics {
         /// ```
         /// use tokio::runtime::Handle;
         ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
+        /// # #[tokio::main(flavor = "current_thread")]
+        /// # async fn main() {
+        /// let metrics = Handle::current().metrics();
         ///
-        ///     let n = metrics.worker_mean_poll_time(0);
-        ///     println!("worker 0 has a mean poll time of {:?}", n);
-        /// }
+        /// let n = metrics.worker_mean_poll_time(0);
+        /// println!("worker 0 has a mean poll time of {:?}", n);
+        /// # }
         /// ```
         #[track_caller]
         pub fn worker_mean_poll_time(&self, worker: usize) -> Duration {
@@ -1004,32 +1029,6 @@ impl RuntimeMetrics {
         }
     }
 
-    cfg_unstable_metrics! {
-        /// Returns the number of tasks currently scheduled in the blocking
-        /// thread pool, spawned using `spawn_blocking`.
-        ///
-        /// This metric returns the **current** number of tasks pending in
-        /// blocking thread pool. As such, the returned value may increase
-        /// or decrease as new tasks are scheduled and processed.
-        ///
-        /// # Examples
-        ///
-        /// ```
-        /// use tokio::runtime::Handle;
-        ///
-        /// #[tokio::main]
-        /// async fn main() {
-        ///     let metrics = Handle::current().metrics();
-        ///
-        ///     let n = metrics.blocking_queue_depth();
-        ///     println!("{} tasks currently pending in the blocking thread pool", n);
-        /// }
-        /// ```
-        pub fn blocking_queue_depth(&self) -> usize {
-            self.handle.inner.blocking_queue_depth()
-        }
-    }
-
     feature! {
         #![all(
             tokio_unstable,
